@@ -335,8 +335,12 @@ class Letter:
         message = input_text.upper()
         for letter in message: 
             if letter != ' ': 
-    
-                cipher += MORSE_CODE_DICT[letter] + ' '
+                try:
+                    
+                    cipher += MORSE_CODE_DICT[letter] + ' '
+                
+                except:
+                    raise Exception('Found invalid characters')
             else: 
                 cipher += ' '
     
@@ -349,10 +353,10 @@ letter, string, String, Str, let, Let = Letter, Letter, Letter, Letter, Letter,
 
 class Detect:
             
-    def asciistring(input, return_type=list):
+    def asciistring(input, return_type=str):
 
         if return_type == list:
-            if True in [c in input for c in "abcdefghijklmnopqrstuvwxyz!@#$%^&*()23456789[];'\,./<>?:|"]:
+            if True in [c in input for c in "abcdefghijklmnopqrstuvwxyz!@#$%^&*()23456789[];'\,./<>?:|-_ABCDEFGHIJKLMNOPQRSTUVWXYZ="]:
 
                 return Letter.asciibinary(input)
             
@@ -360,7 +364,7 @@ class Detect:
                 return asciibinary.Letter(input)
         if return_type == str:
 
-            if True in [c in input for c in "abcdefghijklmnopqrstuvwxyz!@#$%^&*()23456789[];'\,./<>?:|"]:
+            if True in [c in input for c in "abcdefghijklmnopqrstuvwxyz!@#$%^&*()23456789[];'\,./<>?:|-_ABCDEFGHIJKLMNOPQRSTUVWXYZ="]:
 
                 return ' '.join(Letter.asciibinary(input))
             
@@ -431,7 +435,8 @@ class Morse:
                             citext = '' 
                         except:
                             pass
-    
+        if decipher == "":
+            raise Exception("Invalid morse")
         return decipher 
     
     String, Str, letter, Letter = string, string, string, string
