@@ -1,11 +1,17 @@
 class version:
-    class current:
-        name = "0.5.1"
-        release_date = "30th June 2020"
 
     class get_version:
         def __init__(self, search):
-            if search == "0.5.1":
+            if search == "0.5.4":
+                self.name = "0.5.4"
+                self.release_date = "3 July 2020"
+            elif search == "0.5.3":
+                self.name = "0.5.3"
+                self.release_date = "3 July 2020"
+            elif search == "0.5.2":
+                self.name = "0.5.2"
+                self.release_date = "1 July 2020"
+            elif search == "0.5.1":
                 self.name = "0.5.1"
                 self.release_date = "30 June 2020"
             elif search == "0.5.0":
@@ -30,4 +36,5 @@ class version:
                 self.name = "0.1"
                 self.release_date = "27 June 2020"
             else:
-                raise Exception("Invalid release")
\ No newline at end of file
+                raise Exception("Invalid release")
+    current = get_version("0.5.4")
\ No newline at end of file
